@@ -3,7 +3,7 @@ from .reshaper import reshape
 import sys
 from bidi.algorithm import get_display
 __author__ = 'vahid'
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 
 def rtl(exp):
@@ -22,8 +22,4 @@ def main():
         if not l:
             print ''
             continue
-
-        if not l.strip()[0].isdigit():
-            write(rtl(l))
-        else:
-            write(l)
\ No newline at end of file
+        write(rtl(l))
